[![@wq/map][logo]][docs]

**@wq/map** is a plugin for [@wq/app] that adds mapping capabilities.  @wq/map can leverage the [wq configuration object][config] to generate interactive maps for pages rendered via @wq/app.  The generated maps can automatically download and display GeoJSON data rendered by [wq.db's REST API][wq.db] or any third party service.

@wq/map is meant to be used with [@wq/map-gl] or [@wq/leaflet], which respectively provide integration with [Mapbox GL JS] and [Leaflet] mapping APIs.

### [Documentation][docs]

[**Installation**][installation]
&bull;
[**API**][api]
&bull;
[Configuration][configuration]
&bull;
[Components][components]
&bull;
[Hooks][hooks]

[logo]: https://wq.io/images/@wq/map.svg
[docs]: https://wq.io/@wq/map
[installation]: https://wq.io/@wq/map#installation
[api]: https://wq.io/@wq/map#api
[configuration]: https://wq.io/@wq/map#configuration
[components]: https://wq.io/@wq/map#components
[hooks]: https://wq.io/@wq/map#hooks

[@wq/app]: https://wq.io/@wq/app
[@wq/map-gl]: https://wq.io/@wq/map-gl
[@wq/leaflet]: https://github.com/wq/wq.app/tree/main/packages/leaflet
[@wq/map]: https://wq.io/@wq/map
[config]: https://wq.io/config
[wq.db]: https://wq.io/wq.db/

[Mapbox GL JS]: https://docs.mapbox.com/mapbox-gl-js/
[Leaflet]: https://leafletjs.com/
